# protosearch
Software for enumerating crystal structure prototypes to by used for active learning exploration with DFT and machine learning.

## Installation
Using the setup script:

```sh
$ python setup.py install
```
